#! python

import os, shutil, sys, errno

class Copy (): 
    """ 
    Copy a specific file extension in the tree directory 
    """

    def __init__ (self, from_path, to_path, extention): 
        """
        Constructor of class. Get paths and extension. Generate file list
        """

        self.from_path = from_path
        self.to_path = to_path
        self.extention = extention
        self.files = [] 

        self.__verify_paths ()

        self.__find_files()
        self.__copy_files()

    def __verify_paths (self):
        """
        Verify is the from and the to path exist in the pc
        """ 

        # Verify the paths
        if not os.path.exists (self.from_path): 
            raise FileNotFoundError(errno.ENOENT, os.strerror(errno.ENOENT), self.from_path)
        
        if not os.path.exists (self.to_path): 
            raise FileNotFoundError(errno.ENOENT, os.strerror(errno.ENOENT), self.to_path)

    def __find_files (self): 
        """
        Search all files inside the from folder, and save the 
        full path of the files that match the searched extension.
        """

        # Check correct extension
        if not self.extention.startswith('.'): 
            self.extention = '.' + self.extention #Add a dot

        absPath = os.path.abspath(self.from_path)

        # walk inside the origin tree
        for folder_name, subfolder_name, file_names in os.walk(absPath): 
            
            # if the file has the correct extension, save complite path
            for file in file_names: 
                if file.endswith(self.extention):
                    self.files.append(os.path.join(folder_name, file))
    
    def __copy_files (self):
        """ 
        Loop inside a list of files and copy to destiny
        """

        # Check if exist files in file list
        if self.files: 

            absPath = os.path.abspath(self.to_path)

            for file in self.files: 
                print ('Copying "{}" to "{}" ...'.format (file, absPath))
                shutil.copy(file, absPath)
        else: 
            print ("No files found in from folder")



#! python3
import os
from setuptools import setup, find_packages

# read the contents of your README file
this_directory = os.path.abspath(os.path.dirname(__file__))
with open(os.path.join(this_directory, 'README.md')) as f:
    long_description = f.read()

setup (
	name = "selective_copy_files",
	version = "1.0.0", 
	description = "Copy to a specific folder, all files within a directory, that match a particular extension",
	long_description = long_description,
	long_description_content_type = "text/markdown",
	author = "Dari Developer",
	author_email = "hernandezdarifrancisco@gmail.com",
	license = "MIT",
	keywords = "copy, slective copy, filter files, auto copy, selective-copy, filter-files, auto-copy",
	project_urls = {
		"Documentation": "https://github.com/DariHernandez/selective_copy_files/blob/master/README.md",
		"Funding": "https://www.paypal.com/paypalme/FranciscoDari",
		"Source": "https://github.com/DariHernandez/selective_copy_files"
		},
	packages = find_packages(include=["selective_copy_files", "selective_copy_files.*"]),
	install_requires = [],
	python_requires = ">=3.7"
)
